==> vtk-6.3.0-5-aarch64.pkg.tar.xz: vtk/vtkSocketController.java <==
// java wrapper for vtkSocketController object
//

package vtk;
import vtk.*;

public class vtkSocketController extends vtkMultiProcessController
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void Initialize_2();
  public void Initialize()
    { Initialize_2(); }

  private native void Finalize_3();
  public void Finalize()
    { Finalize_3(); }

  private native void Finalize_4(int id0);
  public void Finalize(int id0)
    { Finalize_4(id0); }

  private native void SingleMethodExecute_5();
  public void SingleMethodExecute()
    { SingleMethodExecute_5(); }

  private native void MultipleMethodExecute_6();
  public void MultipleMethodExecute()
    { MultipleMethodExecute_6(); }

  private native void CreateOutputWindow_7();
  public void CreateOutputWindow()
    { CreateOutputWindow_7(); }

  private native int WaitForConnection_8(int id0);
  public int WaitForConnection(int id0)
    { return WaitForConnection_8(id0); }

  private native void CloseConnection_9();
  public void CloseConnection()
    { CloseConnection_9(); }

  private native int ConnectTo_10(String id0,int id1);
  public int ConnectTo(String id0,int id1)
    { return ConnectTo_10(id0,id1); }

  private native int GetSwapBytesInReceivedData_11();
  public int GetSwapBytesInReceivedData()
    { return GetSwapBytesInReceivedData_11(); }

  private native void SetCommunicator_12(vtkSocketCommunicator id0);
  public void SetCommunicator(vtkSocketCommunicator id0)
    { SetCommunicator_12(id0); }

  private native long CreateCompliantController_13();
  public vtkMultiProcessController CreateCompliantController() {
    long temp = CreateCompliantController_13();

    if (temp == 0) return null;
    return (vtkMultiProcessController)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  public vtkSocketController() { super(); }

  public vtkSocketController(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-20-aarch64.pkg.tar.xz: vtk/vtkSocketController.java <==
// java wrapper for vtkSocketController object
//

package vtk;
import vtk.*;

public class vtkSocketController extends vtkMultiProcessController
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void Initialize_2();
  public void Initialize()
    { Initialize_2(); }

  private native void Finalize_3();
  public void Finalize()
    { Finalize_3(); }

  private native void Finalize_4(int id0);
  public void Finalize(int id0)
    { Finalize_4(id0); }

  private native void SingleMethodExecute_5();
  public void SingleMethodExecute()
    { SingleMethodExecute_5(); }

  private native void MultipleMethodExecute_6();
  public void MultipleMethodExecute()
    { MultipleMethodExecute_6(); }

  private native void CreateOutputWindow_7();
  public void CreateOutputWindow()
    { CreateOutputWindow_7(); }

  private native int WaitForConnection_8(int id0);
  public int WaitForConnection(int id0)
    { return WaitForConnection_8(id0); }

  private native void CloseConnection_9();
  public void CloseConnection()
    { CloseConnection_9(); }

  private native int ConnectTo_10(String id0,int id1);
  public int ConnectTo(String id0,int id1)
    { return ConnectTo_10(id0,id1); }

  private native int GetSwapBytesInReceivedData_11();
  public int GetSwapBytesInReceivedData()
    { return GetSwapBytesInReceivedData_11(); }

  private native void SetCommunicator_12(vtkSocketCommunicator id0);
  public void SetCommunicator(vtkSocketCommunicator id0)
    { SetCommunicator_12(id0); }

  private native long CreateCompliantController_13();
  public vtkMultiProcessController CreateCompliantController() {
    long temp = CreateCompliantController_13();

    if (temp == 0) return null;
    return (vtkMultiProcessController)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  public vtkSocketController() { super(); }

  public vtkSocketController(long id) { super(id); }
  public native long   VTKInit();

}
